@@ -67,6 +67,8 @@ class WebView(WebKit2.WebView):
         """
         webview = WebKit2.WebView.new_with_related_view(related)
         webview.__class__ = WebViewMeta
+        # Related view are linked to related context, can't do anything about
+        # this
         webview.__init(related, related.context,
                        related.content_manager, window, None)
         return webview
@@ -169,8 +171,13 @@ class WebView(WebKit2.WebView):
         context = self.get_context()
         codes = App().websettings.get_languages(uri)
         # If None, default user language
-        if codes is not None and\
-                context.get_spell_checking_languages() != codes:
+        if codes is None:
+            locales = GLib.get_language_names()
+            try:
+                codes = [locales[0].split(".")[0]]
+            except:
+                codes = None
+        if context.get_spell_checking_languages() != codes:
             context.set_spell_checking_languages(codes)
 
     def add_text_entry(self, text):
@@ -483,7 +490,6 @@ class WebView(WebKit2.WebView):
                                   App().settings.get_value(
                                       "font-serif").get_string())
         settings.set_property("auto-load-images", True)
-        settings.set_property("enable-media-stream", True)
         settings.set_property("enable-site-specific-quirks", True)
         settings.set_property("allow-universal-access-from-file-urls", False)
         settings.set_property("allow-file-access-from-file-urls", False)
@@ -546,33 +552,6 @@ class WebView(WebKit2.WebView):
             @param related as WebView
             @param navigation_action as WebKit2.NavigationAction
         """
-        GLib.idle_add(self.__wait_for_uri, webview, related, navigation_action)
-
-    def __wait_for_uri(self, webview, related, navigation_action):
-        """
-            Add a new webview with related as soon an URI is available
-            @param webview as WebView
-            @param related as WebView
-            @param navigation_action as WebKit2.NavigationAction
-        """
-        uri = webview.uri
-        # We need an URI for adblocking
-        if not webview.uri:
-            GLib.idle_add(self.__wait_for_uri, webview,
-                          related, navigation_action)
-            return
-        # Block ads
-        parsed = urlparse(uri)
-        if App().settings.get_value("adblock") and\
-                parsed.scheme in ["http", "https"] and\
-                not App().adblock_exceptions.find_parsed(parsed):
-            if App().adblock.is_netloc_blocked(parsed.netloc) or\
-                    App().adblock.is_uri_blocked(uri,
-                                                 parsed.netloc):
-                Logger.debug("WebView::__wait_for_uri(): blocking %s ->%s",
-                             uri, self.uri)
-                webview.destroy()
-                return
         popup_block = App().settings.get_value("popupblock")
         if related.uri is not None:
             parsed_related = urlparse(related.uri)
@@ -582,6 +561,7 @@ class WebView(WebKit2.WebView):
         else:
             exception = False
 
+        properties = webview.get_window_properties()
         if not exception and popup_block and\
                 navigation_action.get_navigation_type() in [
                     WebKit2.NavigationType.OTHER,
@@ -592,9 +572,7 @@ class WebView(WebKit2.WebView):
             if related == self._window.container.current.webview:
                 self._window.toolbar.title.show_indicator(
                     Indicator.POPUPS)
-            return
-        properties = webview.get_window_properties()
-        if (properties.get_toolbar_visible() or
+        elif (properties.get_toolbar_visible() or
                 properties.get_scrollbars_visible()) and\
                 not self._window.modifiers & Gdk.ModifierType.SHIFT_MASK:
             self._window.container.add_webview_with_new_view(
