@@ -94,7 +94,7 @@ class WebViewArtwork:
                 self.emit("favicon-changed", None)
         elif event == WebKit2.LoadEvent.FINISHED:
             is_http = parsed.scheme in ["http", "https"]
-            GLib.idle_add(self.__set_snapshot, is_http)
+            GLib.timeout_add(1000, self.__set_snapshot, is_http)
             if is_http:
                 favicon_database = self.context.get_favicon_database()
                 GLib.timeout_add(2000,
@@ -176,14 +176,14 @@ class WebViewArtwork:
         """
         self.__save_favicon_timeout_id = None
         # Save favicon for URI
-        if not App().art.exists(uri, "favicon"):
+        if not App().art.exists(uri, favicon_type):
             self.__helper.run(App().art.save_artwork,
                               uri,
                               surface,
                               favicon_type)
         # Save favicon for initial URI
         if initial_uri is not None and\
-                not App().art.exists(initial_uri, "favicon"):
+                not App().art.exists(initial_uri, favicon_type):
             striped_uri = uri.rstrip("/")
             if initial_uri != striped_uri:
                 self.__helper.run(App().art.save_artwork,
@@ -198,7 +198,7 @@ class WebViewArtwork:
             @param param as GObject.ParamSpec
         """
         if not webview.is_loading() and not webview.ephemeral:
-            GLib.timeout_add(500, self.__set_snapshot, True)
+            GLib.timeout_add(1000, self.__set_snapshot, True)
 
     def __on_get_favicon(self, favicon_db, result, uri, initial_uri, builtin):
         """
