@@ -105,7 +105,6 @@ class WebViewNavigation:
         App().history.set_page_state(uri)
         self.__switch_profile(uri)
         self.__update_bookmark_metadata(uri)
-        self.__hw_acceleration_policy(parsed.netloc)
         self.content_manager.remove_all_style_sheets()
         # Can't find a way to block content for ephemeral views
         if App().settings.get_value("adblock") and\
@@ -153,7 +152,24 @@ class WebViewNavigation:
             @param event as WebKit2.LoadEvent
         """
         parsed = urlparse(self._uri)
-        if event == WebKit2.LoadEvent.COMMITTED:
+        if event == WebKit2.LoadEvent.STARTED:
+            self.emit("uri-changed", self._uri)
+        elif event == WebKit2.LoadEvent.REDIRECTED:
+            # Block ads
+            if App().settings.get_value("adblock") and\
+                    webview.__related_view is not None and\
+                    parsed.scheme in ["http", "https"] and\
+                    not App().adblock_exceptions.find_parsed(parsed):
+                if App().adblock.is_netloc_blocked(parsed.netloc) or\
+                        App().adblock.is_uri_blocked(self._uri,
+                                                     parsed.netloc):
+                    Logger.debug("WebView::__wait_for_uri(): blocking %s",
+                                 self._uri)
+                    webview.stop_loading()
+                    self._window.container.close_view(self.view)
+                    return
+        elif event == WebKit2.LoadEvent.COMMITTED:
+            self.emit("uri-changed", self._uri)
             http_scheme = parsed.scheme in ["http", "https"]
             self.update_zoom_level()
             # Setup eolie internal adblocker
@@ -216,18 +232,6 @@ class WebViewNavigation:
             App().bookmarks.set_access_time(uri, round(time(), 2))
             App().bookmarks.set_more_popular(uri)
 
-    def __hw_acceleration_policy(self, netloc):
-        """
-            Disable hw acceleration for blacklist
-            @param netloc as str
-        """
-        blacklist = ["plus.google.com"]
-        if netloc in blacklist:
-            policy = WebKit2.HardwareAccelerationPolicy.NEVER
-        else:
-            policy = WebKit2.HardwareAccelerationPolicy.ON_DEMAND
-        self.get_settings().set_hardware_acceleration_policy(policy)
-
     def __switch_profile(self, uri):
         """
             Handle cookies manager
@@ -277,13 +281,13 @@ class WebViewNavigation:
             @param webview as WebKit2.WebView
             @param param as GObject.ParamSpec
         """
-        uri = webview.get_property(param.name)
-        # JS bookmark (Bookmarklet)
-        if not uri.startswith("javascript:"):
-            self.emit("uri-changed", uri)
         # Js update, force favicon caching for current uri
         if not self.is_loading():
-            self.set_current_favicon()
+            uri = webview.get_property(param.name)
+            # JS bookmark (Bookmarklet)
+            if not uri.startswith("javascript:"):
+                self.emit("uri-changed", uri)
+                self.set_current_favicon()
 
     def __on_title_changed(self, webview, param):
         """
@@ -365,9 +369,13 @@ class WebViewNavigation:
                 self.new_page(navigation_uri, LoadingType.FOREGROUND)
                 decision.ignore()
                 return True
+            elif App().phishing.is_phishing(navigation_uri):
+                self._show_phishing_error(navigation_uri)
+                decision.ignore()
+                return True
             else:
-                decision.use()
                 self._error = False
+                decision.use()
                 return False
         elif mouse_button == 1:
             if decision_type == WebKit2.PolicyDecisionType.NEW_WINDOW_ACTION:
@@ -386,16 +394,15 @@ class WebViewNavigation:
                 self.new_page(navigation_uri, LoadingType.POPOVER)
                 decision.ignore()
                 return True
+            elif App().phishing.is_phishing(navigation_uri):
+                self._show_phishing_error(navigation_uri)
+                decision.ignore()
+                return True
             else:
                 self.update_settings_for_uri(navigation_uri)
-                if App().phishing.is_phishing(navigation_uri):
-                    self._show_phishing_error(navigation_uri)
-                    decision.ignore()
-                    return True
-                else:
-                    self._error = False
-                    decision.use()
-                    return False
+                self._error = False
+                decision.use()
+                return False
         else:
             self.new_page(navigation_uri, LoadingType.BACKGROUND)
             decision.ignore()
